Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(39)

Unified Diff: chrome/browser/password_manager/encryptor.h

Issue 28292: Convert encryptor.cc and friends to string16. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/string16.cc ('k') | chrome/browser/password_manager/encryptor.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/password_manager/encryptor.h
===================================================================
--- chrome/browser/password_manager/encryptor.h (revision 10646)
+++ chrome/browser/password_manager/encryptor.h (working copy)
@@ -3,27 +3,28 @@
// found in the LICENSE file.
// A class for encrypting/decrypting strings
-#ifndef CHROME_BROWSER_ENCRYPTOR_H__
-#define CHROME_BROWSER_ENCRYPTOR_H__
+#ifndef CHROME_BROWSER_PASSWORD_MANAGER_ENCRYPTOR_H__
+#define CHROME_BROWSER_PASSWORD_MANAGER_ENCRYPTOR_H__
#include <string>
#include "base/values.h"
+#include "base/string16.h"
class Encryptor {
-public:
- // Encrypt a wstring. The output (second argument) is
+ public:
+ // Encrypt a string16. The output (second argument) is
// really an array of bytes, but we're passing it back
// as a std::string
- static bool EncryptWideString(const std::wstring& plaintext,
- std::string* ciphertext);
+ static bool EncryptString16(const string16& plaintext,
+ std::string* ciphertext);
- // Decrypt an array of bytes obtained with EnctryptWideString
- // back into a wstring. Note that the input (first argument)
+ // Decrypt an array of bytes obtained with EncryptString16
+ // back into a string16. Note that the input (first argument)
// is a std::string, so you need to first get your (binary)
// data into a string.
- static bool DecryptWideString(const std::string& ciphertext,
- std::wstring* plaintext);
+ static bool DecryptString16(const std::string& ciphertext,
+ string16* plaintext);
// Encrypt a string.
static bool EncryptString(const std::string& plaintext,
@@ -36,9 +37,8 @@
static bool DecryptString(const std::string& ciphertext,
std::string* plaintext);
-private:
+ private:
DISALLOW_IMPLICIT_CONSTRUCTORS(Encryptor);
};
-#endif // CHROME_BROWSER_ENCRYPTOR_H__
-
+#endif // CHROME_BROWSER_PASSWORD_MANAGER_ENCRYPTOR_H__
« no previous file with comments | « base/string16.cc ('k') | chrome/browser/password_manager/encryptor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698